==> theia-0.1.8.8-py3-none-any.whl: theia/aws/containers/ec2.py <==
import pulumi
from pulumi_aws import ec2
from pydantic.dataclasses import dataclass, ConfigDict
from typing import Optional, Mapping, List

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION

logger = Logger("ec2")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class InstanceSettings:
    ami_name: Optional[str] = None
    ami_id: Optional[str] = None
    instance_type: Optional[str] = None
    subnet_id: Optional[str] = None
    key_name: Optional[str] = None
    associate_public_ip_address: Optional[bool] = False
    security_groups: Optional[List[str]] = None


class Instance():
    def __new__(
        cls,
        resource_name: str,
        settings: Optional[InstanceSettings] = InstanceSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.DomainArgs:

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating ec2 instance {resource_name}")

        if settings.ami_name:
            ami = ec2.get_ami(
                most_recent=True,
                filters=[
                    ec2.GetAmiFilterArgs(
                        name="name",
                        values=[settings.ami_name],
                    )
                ]
            )

        instance_args = ec2.InstanceArgs(
            ami=settings.ami_id if settings.ami_id else ami.id,
            instance_type=settings.instance_type,
            subnet_id=settings.subnet_id,
            key_name=settings.key_name,
            associate_public_ip_address=settings.associate_public_ip_address,
            security_groups=settings.security_groups,
            tags=merged_tags
        )
        
        instance_out=ec2.Domain(
            resource_name=resource_name,
            args=instance_args,
            opts=opts
        )

        pulumi.export(
            f"ec2-instance---{resource_name}",
            {
                "id": instance_out.id,
                "arn": instance_out.arn
            },
        )

        return instance_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.Domain:
        stack_ref = StackRegistry.get(stack_name=stack)
        instance = stack_ref.get_output(name=f"ec2-instance---{resource_name}")
        return ec2.Domain.get(resource_name=resource_name, id=instance["id"])

==> theia-0.1.8.9-py3-none-any.whl: theia/aws/containers/ec2.py <==
import pulumi
from pulumi import Output
from pulumi_aws import ec2
from pydantic.dataclasses import dataclass, ConfigDict
from typing import Optional, Mapping, List

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION

logger = Logger("ec2")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class InstanceSettings:
    ami_name: Optional[str] = None
    ami_id: Optional[str] = None
    instance_type: Optional[str] = None
    subnet_id: Optional[str] = None
    key_name: Optional[str] = None
    associate_public_ip_address: Optional[bool] = False
    security_groups: Optional[List[str | Output[str]]] = None
    iam_instance_profile: Optional[str] = None

class Instance():
    def __new__(
        cls,
        resource_name: str,
        settings: Optional[InstanceSettings] = InstanceSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.InstanceArgs:

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating ec2 instance {resource_name}")

        if settings.ami_name:
            ami = ec2.get_ami(
                most_recent=True,
                filters=[
                    ec2.GetAmiFilterArgs(
                        name="name",
                        values=[settings.ami_name],
                    )
                ]
            )

        instance_args = ec2.InstanceArgs(
            ami=settings.ami_id if settings.ami_id else ami.id,
            instance_type=settings.instance_type,
            subnet_id=settings.subnet_id,
            key_name=settings.key_name,
            associate_public_ip_address=settings.associate_public_ip_address,
            vpc_security_group_ids=settings.security_groups,
            iam_instance_profile=settings.iam_instance_profile,
            tags=merged_tags
        )
        
        instance_out=ec2.Instance(
            resource_name=resource_name,
            args=instance_args,
            opts=opts
        )

        pulumi.export(
            f"ec2-instance---{resource_name}",
            {
                "id": instance_out.id,
                "arn": instance_out.arn
            },
        )

        return instance_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.Instance:
        stack_ref = StackRegistry.get(stack_name=stack)
        instance = stack_ref.get_output(name=f"ec2-instance---{resource_name}")
        return ec2.Instance.get(resource_name=resource_name, id=instance["id"])
